pub struct PyStrategy { /* private fields */ }Expand description
Python-facing wrapper for Strategy.
Implementations
Sourceimpl PyStrategy
impl PyStrategy
Sourcepub fn new(config: Option<StrategyConfig>) -> Self
pub fn new(config: Option<StrategyConfig>) -> Self
Creates a new PyStrategy instance.
Sourcepub fn set_python_instance(&mut self, py_obj: Py<PyAny>)
pub fn set_python_instance(&mut self, py_obj: Py<PyAny>)
Sets the Python instance reference for method dispatch.
Sourcepub fn set_strategy_id(&mut self, strategy_id: StrategyId)
pub fn set_strategy_id(&mut self, strategy_id: StrategyId)
Updates the strategy_id (actor_id) in both the core config and the actor_id field.
Must only be called before registration. See PyDataActor::set_actor_id.
Sourcepub fn set_log_events(&mut self, log_events: bool)
pub fn set_log_events(&mut self, log_events: bool)
Updates the log_events setting in the core config.
Sourcepub fn set_log_commands(&mut self, log_commands: bool)
pub fn set_log_commands(&mut self, log_commands: bool)
Updates the log_commands setting in the core config.
Sourcepub fn strategy_id(&self) -> StrategyId
pub fn strategy_id(&self) -> StrategyId
Returns the strategy ID.
Sourcepub fn is_registered(&self) -> bool
pub fn is_registered(&self) -> bool
Returns a value indicating whether the strategy has been registered with a trader.
Sourcepub fn register(
&mut self,
trader_id: TraderId,
clock: Rc<RefCell<dyn Clock>>,
cache: Rc<RefCell<Cache>>,
portfolio: Rc<RefCell<Portfolio>>,
) -> Result<()>
pub fn register( &mut self, trader_id: TraderId, clock: Rc<RefCell<dyn Clock>>, cache: Rc<RefCell<Cache>>, portfolio: Rc<RefCell<Portfolio>>, ) -> Result<()>
Sourcepub fn register_in_global_registries(&self)
pub fn register_in_global_registries(&self)
Registers this strategy in the global component and actor registries.